@@ -11,7 +11,7 @@ from functools import partial
 import torch
 
 from ultralytics.utils.downloads import attempt_download_asset
-from ultralytics.utils.torch_utils import TORCH_1_13
+from ultralytics.utils.patches import torch_load
 
 from .modules.decoders import MaskDecoder
 from .modules.encoders import FpnNeck, Hiera, ImageEncoder, ImageEncoderViT, MemoryEncoder, PromptEncoder
@@ -207,7 +207,7 @@ def _build_sam(
     if checkpoint is not None:
         checkpoint = attempt_download_asset(checkpoint)
         with open(checkpoint, "rb") as f:
-            state_dict = torch.load(f, weights_only=False) if TORCH_1_13 else torch.load(f)
+            state_dict = torch_load(f)
         sam.load_state_dict(state_dict)
     sam.eval()
     return sam
@@ -301,7 +301,7 @@ def _build_sam2(
     if checkpoint is not None:
         checkpoint = attempt_download_asset(checkpoint)
         with open(checkpoint, "rb") as f:
-            state_dict = (torch.load(f, weights_only=False) if TORCH_1_13 else torch.load(f))["model"]
+            state_dict = torch_load(f)["model"]
         sam2.load_state_dict(state_dict)
     sam2.eval()
     return sam2
